function varargout = move_GUI(varargin)
% MOVE_GUI MATLAB code for move_GUI.fig
%      MOVE_GUI, by itself, creates a new MOVE_GUI or raises the existing
%      singleton*.
%
%      H = MOVE_GUI returns the handle to a new MOVE_GUI or the handle to
%      the existing singleton*.
%
%      MOVE_GUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in MOVE_GUI.M with the given input arguments.
%
%      MOVE_GUI('Property','Value',...) creates a new MOVE_GUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before move_GUI_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to move_GUI_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help move_GUI

% Last Modified by GUIDE v2.5 14-Nov-2017 14:48:42

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @move_GUI_OpeningFcn, ...
                   'gui_OutputFcn',  @move_GUI_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before move_GUI is made visible.
function move_GUI_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to move_GUI (see VARARGIN)
handles = guidata(hObject);

% Choose default command line output for move_GUI
handles.output = hObject;


% Update handles structure
guidata(hObject, handles);




% UIWAIT makes move_GUI wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = move_GUI_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure


varargout{1} = handles.output;


% --- Executes on button press in up.
function [i]= up_Callback(hObject, eventdata, handles)
% hObject    handle to up (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global i
global q
i=1
q=1
varargout{1} = i
varargout{1} = q




% --- Executes on button press in up.
%function up_Callback(hObject, eventdata, handles)
% hObject    handle to up (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%guidata(hObject, handles);



% --- Executes on button press in left.
function left_Callback(hObject, eventdata, handles)
% hObject    handle to left (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global i
global q
i=1
q=3
varargout{1} = i
varargout{1} = q


% --- Executes on button press in down.
function down_Callback(hObject, eventdata, handles)
% hObject    handle to down (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global i
global q
i=1
q=2
varargout{1} = i
varargout{1} = q


% --- Executes on button press in right.
function right_Callback(hObject, eventdata, handles)
% hObject    handle to right (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global i
global q
i=1
q=4
varargout{1} = i
varargout{1} = q


% --- Executes on button press in stop.
function stop_Callback(hObject, eventdata, handles)
% hObject    handle to stop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global i
global q
i=1
q=5
varargout{1} = i
varargout{1} = q


% --- Executes on button press in horn.
function horn_Callback(hObject, eventdata, handles)
% hObject    handle to horn (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global i
global q
i=1
q=6
varargout{1} = i
varargout{1} = q


% --- Executes on button press in preci.
function preci_Callback(hObject, eventdata, handles)
% hObject    handle to preci (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

global p

p=1

varargout{1} = p

% --- Executes on button press in picture.
function picture_Callback(hObject, eventdata, handles)
% hObject    handle to picture (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global i
global q
i=1
q=7
varargout{1} = i
varargout{1} = q


% --- Executes on button press in left_curve.
function left_curve_Callback(hObject, eventdata, handles)
% hObject    handle to left_curve (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global i
global q
i=1
q=8
varargout{1} = i
varargout{1} = q

% --- Executes on button press in right_curve.
function right_curve_Callback(hObject, eventdata, handles)
% hObject    handle to right_curve (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global i
global q
i=1
q=9
varargout{1} = i
varargout{1} = q


% --- Executes on button press in rec.
function rec_Callback(hObject, eventdata, handles)
% hObject    handle to rec (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global record
record=2
varargout{1}=record


% --- Executes on button press in con.
function con_Callback(hObject, eventdata, handles)
% hObject    handle to con (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global record
record=1
varargout{1}=record


% --- Executes on button press in play.
function play_Callback(hObject, eventdata, handles)
% hObject    handle to play (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global record
record=3
varargout{1}=record
